<?php
namespace PHPMaker2019\project_germanos;

// Session
if (session_status() !== PHP_SESSION_ACTIVE)
	session_start(); // Init session data

// Output buffering
ob_start(); 

// Autoload
include_once "autoload.php";
?>
<?php

// Write header
WriteHeader(FALSE);

// Create page object
$cityzenshipstatus_edit = new cityzenshipstatus_edit();

// Run the page
$cityzenshipstatus_edit->run();

// Setup login status
SetupLoginStatus();
SetClientVar("login", LoginStatus());

// Global Page Rendering event (in userfn*.php)
Page_Rendering();

// Page Rendering event
$cityzenshipstatus_edit->Page_Render();
?>
<?php include_once "header.php" ?>
<script>

// Form object
currentPageID = ew.PAGE_ID = "edit";
var fcityzenshipstatusedit = currentForm = new ew.Form("fcityzenshipstatusedit", "edit");

// Validate form
fcityzenshipstatusedit.validate = function() {
	if (!this.validateRequired)
		return true; // Ignore validation
	var $ = jQuery, fobj = this.getForm(), $fobj = $(fobj);
	if ($fobj.find("#confirm").val() == "F")
		return true;
	var elm, felm, uelm, addcnt = 0;
	var $k = $fobj.find("#" + this.formKeyCountName); // Get key_count
	var rowcnt = ($k[0]) ? parseInt($k.val(), 10) : 1;
	var startcnt = (rowcnt == 0) ? 0 : 1; // Check rowcnt == 0 => Inline-Add
	var gridinsert = ["insert", "gridinsert"].includes($fobj.find("#action").val()) && $k[0];
	for (var i = startcnt; i <= rowcnt; i++) {
		var infix = ($k[0]) ? String(i) : "";
		$fobj.data("rowindex", infix);
		<?php if ($cityzenshipstatus_edit->CityzenshipStatusID->Required) { ?>
			elm = this.getElements("x" + infix + "_CityzenshipStatusID");
			if (elm && !ew.isHidden(elm) && !ew.hasValue(elm))
				return this.onError(elm, "<?php echo JsEncode(str_replace("%s", $cityzenshipstatus->CityzenshipStatusID->caption(), $cityzenshipstatus->CityzenshipStatusID->RequiredErrorMessage)) ?>");
		<?php } ?>
		<?php if ($cityzenshipstatus_edit->CityzenshipStatus->Required) { ?>
			elm = this.getElements("x" + infix + "_CityzenshipStatus");
			if (elm && !ew.isHidden(elm) && !ew.hasValue(elm))
				return this.onError(elm, "<?php echo JsEncode(str_replace("%s", $cityzenshipstatus->CityzenshipStatus->caption(), $cityzenshipstatus->CityzenshipStatus->RequiredErrorMessage)) ?>");
		<?php } ?>
		<?php if ($cityzenshipstatus_edit->Notes->Required) { ?>
			elm = this.getElements("x" + infix + "_Notes");
			if (elm && !ew.isHidden(elm) && !ew.hasValue(elm))
				return this.onError(elm, "<?php echo JsEncode(str_replace("%s", $cityzenshipstatus->Notes->caption(), $cityzenshipstatus->Notes->RequiredErrorMessage)) ?>");
		<?php } ?>

			// Fire Form_CustomValidate event
			if (!this.Form_CustomValidate(fobj))
				return false;
	}

	// Process detail forms
	var dfs = $fobj.find("input[name='detailpage']").get();
	for (var i = 0; i < dfs.length; i++) {
		var df = dfs[i], val = df.value;
		if (val && ew.forms[val])
			if (!ew.forms[val].validate())
				return false;
	}
	return true;
}

// Form_CustomValidate event
fcityzenshipstatusedit.Form_CustomValidate = function(fobj) { // DO NOT CHANGE THIS LINE!

	// Your custom validation code here, return false if invalid.
	return true;
}

// Use JavaScript validation or not
fcityzenshipstatusedit.validateRequired = <?php echo json_encode(CLIENT_VALIDATE) ?>;

// Dynamic selection lists
// Form object for search

</script>
<script>

// Write your client script here, no need to add script tags.
</script>
<?php $cityzenshipstatus_edit->showPageHeader(); ?>
<?php
$cityzenshipstatus_edit->showMessage();
?>
<?php if (!$cityzenshipstatus_edit->IsModal) { ?>
<form name="ew-pager-form" class="form-inline ew-form ew-pager-form" action="<?php echo CurrentPageName() ?>">
<?php if (!isset($cityzenshipstatus_edit->Pager)) $cityzenshipstatus_edit->Pager = new PrevNextPager($cityzenshipstatus_edit->StartRec, $cityzenshipstatus_edit->DisplayRecs, $cityzenshipstatus_edit->TotalRecs, $cityzenshipstatus_edit->AutoHidePager) ?>
<?php if ($cityzenshipstatus_edit->Pager->RecordCount > 0 && $cityzenshipstatus_edit->Pager->Visible) { ?>
<div class="ew-pager">
<span><?php echo $Language->Phrase("Page") ?>&nbsp;</span>
<div class="ew-prev-next"><div class="input-group input-group-sm">
<div class="input-group-prepend">
<!-- first page button -->
	<?php if ($cityzenshipstatus_edit->Pager->FirstButton->Enabled) { ?>
	<a class="btn btn-default" title="<?php echo $Language->phrase("PagerFirst") ?>" href="<?php echo $cityzenshipstatus_edit->pageUrl() ?>start=<?php echo $cityzenshipstatus_edit->Pager->FirstButton->Start ?>"><i class="icon-first ew-icon"></i></a>
	<?php } else { ?>
	<a class="btn btn-default disabled" title="<?php echo $Language->phrase("PagerFirst") ?>"><i class="icon-first ew-icon"></i></a>
	<?php } ?>
<!-- previous page button -->
	<?php if ($cityzenshipstatus_edit->Pager->PrevButton->Enabled) { ?>
	<a class="btn btn-default" title="<?php echo $Language->phrase("PagerPrevious") ?>" href="<?php echo $cityzenshipstatus_edit->pageUrl() ?>start=<?php echo $cityzenshipstatus_edit->Pager->PrevButton->Start ?>"><i class="icon-prev ew-icon"></i></a>
	<?php } else { ?>
	<a class="btn btn-default disabled" title="<?php echo $Language->phrase("PagerPrevious") ?>"><i class="icon-prev ew-icon"></i></a>
	<?php } ?>
</div>
<!-- current page number -->
	<input class="form-control" type="text" name="<?php echo TABLE_PAGE_NO ?>" value="<?php echo $cityzenshipstatus_edit->Pager->CurrentPage ?>">
<div class="input-group-append">
<!-- next page button -->
	<?php if ($cityzenshipstatus_edit->Pager->NextButton->Enabled) { ?>
	<a class="btn btn-default" title="<?php echo $Language->phrase("PagerNext") ?>" href="<?php echo $cityzenshipstatus_edit->pageUrl() ?>start=<?php echo $cityzenshipstatus_edit->Pager->NextButton->Start ?>"><i class="icon-next ew-icon"></i></a>
	<?php } else { ?>
	<a class="btn btn-default disabled" title="<?php echo $Language->phrase("PagerNext") ?>"><i class="icon-next ew-icon"></i></a>
	<?php } ?>
<!-- last page button -->
	<?php if ($cityzenshipstatus_edit->Pager->LastButton->Enabled) { ?>
	<a class="btn btn-default" title="<?php echo $Language->phrase("PagerLast") ?>" href="<?php echo $cityzenshipstatus_edit->pageUrl() ?>start=<?php echo $cityzenshipstatus_edit->Pager->LastButton->Start ?>"><i class="icon-last ew-icon"></i></a>
	<?php } else { ?>
	<a class="btn btn-default disabled" title="<?php echo $Language->phrase("PagerLast") ?>"><i class="icon-last ew-icon"></i></a>
	<?php } ?>
</div>
</div>
</div>
<span>&nbsp;<?php echo $Language->Phrase("of") ?>&nbsp;<?php echo $cityzenshipstatus_edit->Pager->PageCount ?></span>
<div class="clearfix"></div>
</div>
<?php } ?>
<div class="clearfix"></div>
</form>
<?php } ?>
<form name="fcityzenshipstatusedit" id="fcityzenshipstatusedit" class="<?php echo $cityzenshipstatus_edit->FormClassName ?>" action="<?php echo CurrentPageName() ?>" method="post">
<?php if ($cityzenshipstatus_edit->CheckToken) { ?>
<input type="hidden" name="<?php echo TOKEN_NAME ?>" value="<?php echo $cityzenshipstatus_edit->Token ?>">
<?php } ?>
<input type="hidden" name="t" value="cityzenshipstatus">
<input type="hidden" name="action" id="action" value="update">
<input type="hidden" name="modal" value="<?php echo (int)$cityzenshipstatus_edit->IsModal ?>">
<?php if (!$cityzenshipstatus_edit->IsMobileOrModal) { ?>
<div class="ew-desktop"><!-- desktop -->
<?php } ?>
<?php if ($cityzenshipstatus_edit->IsMobileOrModal) { ?>
<div class="ew-edit-div"><!-- page* -->
<?php } else { ?>
<table id="tbl_cityzenshipstatusedit" class="table table-striped table-sm ew-desktop-table"><!-- table* -->
<?php } ?>
<?php if ($cityzenshipstatus->CityzenshipStatusID->Visible) { // CityzenshipStatusID ?>
<?php if ($cityzenshipstatus_edit->IsMobileOrModal) { ?>
	<div id="r_CityzenshipStatusID" class="form-group row">
		<label id="elh_cityzenshipstatus_CityzenshipStatusID" class="<?php echo $cityzenshipstatus_edit->LeftColumnClass ?>"><?php echo $cityzenshipstatus->CityzenshipStatusID->caption() ?><?php echo ($cityzenshipstatus->CityzenshipStatusID->Required) ? $Language->phrase("FieldRequiredIndicator") : "" ?></label>
		<div class="<?php echo $cityzenshipstatus_edit->RightColumnClass ?>"><div<?php echo $cityzenshipstatus->CityzenshipStatusID->cellAttributes() ?>>
<span id="el_cityzenshipstatus_CityzenshipStatusID">
<span<?php echo $cityzenshipstatus->CityzenshipStatusID->viewAttributes() ?>>
<input type="text" readonly class="form-control-plaintext" value="<?php echo RemoveHtml($cityzenshipstatus->CityzenshipStatusID->EditValue) ?>"></span>
</span>
<input type="hidden" data-table="cityzenshipstatus" data-field="x_CityzenshipStatusID" name="x_CityzenshipStatusID" id="x_CityzenshipStatusID" value="<?php echo HtmlEncode($cityzenshipstatus->CityzenshipStatusID->CurrentValue) ?>">
<?php echo $cityzenshipstatus->CityzenshipStatusID->CustomMsg ?></div></div>
	</div>
<?php } else { ?>
	<tr id="r_CityzenshipStatusID">
		<td class="<?php echo $cityzenshipstatus_edit->TableLeftColumnClass ?>"><span id="elh_cityzenshipstatus_CityzenshipStatusID"><?php echo $cityzenshipstatus->CityzenshipStatusID->caption() ?><?php echo ($cityzenshipstatus->CityzenshipStatusID->Required) ? $Language->phrase("FieldRequiredIndicator") : "" ?></span></td>
		<td<?php echo $cityzenshipstatus->CityzenshipStatusID->cellAttributes() ?>>
<span id="el_cityzenshipstatus_CityzenshipStatusID">
<span<?php echo $cityzenshipstatus->CityzenshipStatusID->viewAttributes() ?>>
<input type="text" readonly class="form-control-plaintext" value="<?php echo RemoveHtml($cityzenshipstatus->CityzenshipStatusID->EditValue) ?>"></span>
</span>
<input type="hidden" data-table="cityzenshipstatus" data-field="x_CityzenshipStatusID" name="x_CityzenshipStatusID" id="x_CityzenshipStatusID" value="<?php echo HtmlEncode($cityzenshipstatus->CityzenshipStatusID->CurrentValue) ?>">
<?php echo $cityzenshipstatus->CityzenshipStatusID->CustomMsg ?></td>
	</tr>
<?php } ?>
<?php } ?>
<?php if ($cityzenshipstatus->CityzenshipStatus->Visible) { // CityzenshipStatus ?>
<?php if ($cityzenshipstatus_edit->IsMobileOrModal) { ?>
	<div id="r_CityzenshipStatus" class="form-group row">
		<label id="elh_cityzenshipstatus_CityzenshipStatus" for="x_CityzenshipStatus" class="<?php echo $cityzenshipstatus_edit->LeftColumnClass ?>"><?php echo $cityzenshipstatus->CityzenshipStatus->caption() ?><?php echo ($cityzenshipstatus->CityzenshipStatus->Required) ? $Language->phrase("FieldRequiredIndicator") : "" ?></label>
		<div class="<?php echo $cityzenshipstatus_edit->RightColumnClass ?>"><div<?php echo $cityzenshipstatus->CityzenshipStatus->cellAttributes() ?>>
<span id="el_cityzenshipstatus_CityzenshipStatus">
<input type="text" data-table="cityzenshipstatus" data-field="x_CityzenshipStatus" name="x_CityzenshipStatus" id="x_CityzenshipStatus" size="30" maxlength="15" placeholder="<?php echo HtmlEncode($cityzenshipstatus->CityzenshipStatus->getPlaceHolder()) ?>" value="<?php echo $cityzenshipstatus->CityzenshipStatus->EditValue ?>"<?php echo $cityzenshipstatus->CityzenshipStatus->editAttributes() ?>>
</span>
<?php echo $cityzenshipstatus->CityzenshipStatus->CustomMsg ?></div></div>
	</div>
<?php } else { ?>
	<tr id="r_CityzenshipStatus">
		<td class="<?php echo $cityzenshipstatus_edit->TableLeftColumnClass ?>"><span id="elh_cityzenshipstatus_CityzenshipStatus"><?php echo $cityzenshipstatus->CityzenshipStatus->caption() ?><?php echo ($cityzenshipstatus->CityzenshipStatus->Required) ? $Language->phrase("FieldRequiredIndicator") : "" ?></span></td>
		<td<?php echo $cityzenshipstatus->CityzenshipStatus->cellAttributes() ?>>
<span id="el_cityzenshipstatus_CityzenshipStatus">
<input type="text" data-table="cityzenshipstatus" data-field="x_CityzenshipStatus" name="x_CityzenshipStatus" id="x_CityzenshipStatus" size="30" maxlength="15" placeholder="<?php echo HtmlEncode($cityzenshipstatus->CityzenshipStatus->getPlaceHolder()) ?>" value="<?php echo $cityzenshipstatus->CityzenshipStatus->EditValue ?>"<?php echo $cityzenshipstatus->CityzenshipStatus->editAttributes() ?>>
</span>
<?php echo $cityzenshipstatus->CityzenshipStatus->CustomMsg ?></td>
	</tr>
<?php } ?>
<?php } ?>
<?php if ($cityzenshipstatus->Notes->Visible) { // Notes ?>
<?php if ($cityzenshipstatus_edit->IsMobileOrModal) { ?>
	<div id="r_Notes" class="form-group row">
		<label id="elh_cityzenshipstatus_Notes" for="x_Notes" class="<?php echo $cityzenshipstatus_edit->LeftColumnClass ?>"><?php echo $cityzenshipstatus->Notes->caption() ?><?php echo ($cityzenshipstatus->Notes->Required) ? $Language->phrase("FieldRequiredIndicator") : "" ?></label>
		<div class="<?php echo $cityzenshipstatus_edit->RightColumnClass ?>"><div<?php echo $cityzenshipstatus->Notes->cellAttributes() ?>>
<span id="el_cityzenshipstatus_Notes">
<input type="text" data-table="cityzenshipstatus" data-field="x_Notes" name="x_Notes" id="x_Notes" size="30" maxlength="100" placeholder="<?php echo HtmlEncode($cityzenshipstatus->Notes->getPlaceHolder()) ?>" value="<?php echo $cityzenshipstatus->Notes->EditValue ?>"<?php echo $cityzenshipstatus->Notes->editAttributes() ?>>
</span>
<?php echo $cityzenshipstatus->Notes->CustomMsg ?></div></div>
	</div>
<?php } else { ?>
	<tr id="r_Notes">
		<td class="<?php echo $cityzenshipstatus_edit->TableLeftColumnClass ?>"><span id="elh_cityzenshipstatus_Notes"><?php echo $cityzenshipstatus->Notes->caption() ?><?php echo ($cityzenshipstatus->Notes->Required) ? $Language->phrase("FieldRequiredIndicator") : "" ?></span></td>
		<td<?php echo $cityzenshipstatus->Notes->cellAttributes() ?>>
<span id="el_cityzenshipstatus_Notes">
<input type="text" data-table="cityzenshipstatus" data-field="x_Notes" name="x_Notes" id="x_Notes" size="30" maxlength="100" placeholder="<?php echo HtmlEncode($cityzenshipstatus->Notes->getPlaceHolder()) ?>" value="<?php echo $cityzenshipstatus->Notes->EditValue ?>"<?php echo $cityzenshipstatus->Notes->editAttributes() ?>>
</span>
<?php echo $cityzenshipstatus->Notes->CustomMsg ?></td>
	</tr>
<?php } ?>
<?php } ?>
<?php if ($cityzenshipstatus_edit->IsMobileOrModal) { ?>
</div><!-- /page* -->
<?php } else { ?>
</table><!-- /table* -->
<?php } ?>
<?php if (!$cityzenshipstatus_edit->IsModal) { ?>
<div class="form-group row"><!-- buttons .form-group -->
	<div class="<?php echo $cityzenshipstatus_edit->OffsetColumnClass ?>"><!-- buttons offset -->
<button class="btn btn-primary ew-btn" name="btn-action" id="btn-action" type="submit"><?php echo $Language->phrase("SaveBtn") ?></button>
<button class="btn btn-default ew-btn" name="btn-cancel" id="btn-cancel" type="button" data-href="<?php echo $cityzenshipstatus_edit->getReturnUrl() ?>"><?php echo $Language->phrase("CancelBtn") ?></button>
	</div><!-- /buttons offset -->
</div><!-- /buttons .form-group -->
<?php } ?>
<?php if (!$cityzenshipstatus_edit->IsMobileOrModal) { ?>
</div><!-- /desktop -->
<?php } ?>
<?php if (!$cityzenshipstatus_edit->IsModal) { ?>
<?php if (!isset($cityzenshipstatus_edit->Pager)) $cityzenshipstatus_edit->Pager = new PrevNextPager($cityzenshipstatus_edit->StartRec, $cityzenshipstatus_edit->DisplayRecs, $cityzenshipstatus_edit->TotalRecs, $cityzenshipstatus_edit->AutoHidePager) ?>
<?php if ($cityzenshipstatus_edit->Pager->RecordCount > 0 && $cityzenshipstatus_edit->Pager->Visible) { ?>
<div class="ew-pager">
<span><?php echo $Language->Phrase("Page") ?>&nbsp;</span>
<div class="ew-prev-next"><div class="input-group input-group-sm">
<div class="input-group-prepend">
<!-- first page button -->
	<?php if ($cityzenshipstatus_edit->Pager->FirstButton->Enabled) { ?>
	<a class="btn btn-default" title="<?php echo $Language->phrase("PagerFirst") ?>" href="<?php echo $cityzenshipstatus_edit->pageUrl() ?>start=<?php echo $cityzenshipstatus_edit->Pager->FirstButton->Start ?>"><i class="icon-first ew-icon"></i></a>
	<?php } else { ?>
	<a class="btn btn-default disabled" title="<?php echo $Language->phrase("PagerFirst") ?>"><i class="icon-first ew-icon"></i></a>
	<?php } ?>
<!-- previous page button -->
	<?php if ($cityzenshipstatus_edit->Pager->PrevButton->Enabled) { ?>
	<a class="btn btn-default" title="<?php echo $Language->phrase("PagerPrevious") ?>" href="<?php echo $cityzenshipstatus_edit->pageUrl() ?>start=<?php echo $cityzenshipstatus_edit->Pager->PrevButton->Start ?>"><i class="icon-prev ew-icon"></i></a>
	<?php } else { ?>
	<a class="btn btn-default disabled" title="<?php echo $Language->phrase("PagerPrevious") ?>"><i class="icon-prev ew-icon"></i></a>
	<?php } ?>
</div>
<!-- current page number -->
	<input class="form-control" type="text" name="<?php echo TABLE_PAGE_NO ?>" value="<?php echo $cityzenshipstatus_edit->Pager->CurrentPage ?>">
<div class="input-group-append">
<!-- next page button -->
	<?php if ($cityzenshipstatus_edit->Pager->NextButton->Enabled) { ?>
	<a class="btn btn-default" title="<?php echo $Language->phrase("PagerNext") ?>" href="<?php echo $cityzenshipstatus_edit->pageUrl() ?>start=<?php echo $cityzenshipstatus_edit->Pager->NextButton->Start ?>"><i class="icon-next ew-icon"></i></a>
	<?php } else { ?>
	<a class="btn btn-default disabled" title="<?php echo $Language->phrase("PagerNext") ?>"><i class="icon-next ew-icon"></i></a>
	<?php } ?>
<!-- last page button -->
	<?php if ($cityzenshipstatus_edit->Pager->LastButton->Enabled) { ?>
	<a class="btn btn-default" title="<?php echo $Language->phrase("PagerLast") ?>" href="<?php echo $cityzenshipstatus_edit->pageUrl() ?>start=<?php echo $cityzenshipstatus_edit->Pager->LastButton->Start ?>"><i class="icon-last ew-icon"></i></a>
	<?php } else { ?>
	<a class="btn btn-default disabled" title="<?php echo $Language->phrase("PagerLast") ?>"><i class="icon-last ew-icon"></i></a>
	<?php } ?>
</div>
</div>
</div>
<span>&nbsp;<?php echo $Language->Phrase("of") ?>&nbsp;<?php echo $cityzenshipstatus_edit->Pager->PageCount ?></span>
<div class="clearfix"></div>
</div>
<?php } ?>
<div class="clearfix"></div>
<?php } ?>
</form>
<?php
$cityzenshipstatus_edit->showPageFooter();
if (DEBUG_ENABLED)
	echo GetDebugMessage();
?>
<script>

// Write your table-specific startup script here
// document.write("page loaded");

</script>
<?php include_once "footer.php" ?>
<?php
$cityzenshipstatus_edit->terminate();
?>
